'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.date = undefined;

var _date = require('./lib/date');

/*
 * Checks for a 'date'
 * @param date
 * @return boolean
 */
var isDate = function isDate(date) {
  return (0, _date._isDate)(date);
};

/*
 * Validates that 'date' is less than or equal to (<=) the value
 * @param max
 * @return boolean
 */
var maxDate = function maxDate() {
  var max = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : new Date(3000, 1, 1);
  return function (value) {
    return (0, _date._isDate)(value) && value <= max;
  };
};

/*
 * Validates that 'date' is greater than or equal to (>=) the value
 * @param min
 * @return boolean
 */
var minDate = function minDate() {
  var min = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : new Date(1900, 1, 1);
  return function (value) {
    return (0, _date._isDate)(value) && value >= min;
  };
};

/*
 * Validates if date is within the range
 * @param min
 * @param max
 * @return boolean
 */
var between = function between() {
  var min = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : new Date(1900, 1, 1);
  var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : new Date(3000, 1, 1);
  return function (value) {
    return minDate(min)(value) && maxDate(max)(value);
  };
};

/*
 * Export constant date
 */
var date = exports.date = {
  maxDate: maxDate,
  minDate: minDate,
  between: between,
  isDate: isDate
};